@@ -29,3 +29,8 @@ class mtimeAdapter(object):
             return time.time()
         else:
             return IPersistent(self.context)._p_mtime
+
+    def strftime(self,format=u"%Y-%m-%d %H:%M:%S") :
+        """ Return datetime as string using format argument """
+        return time.strftime(format,time.localtime(self.mtime))
+        
\ No newline at end of file
