@@ -2,11 +2,11 @@
 #######################################################################
 """ Any Interface Adapter to IPager Interface
 
-$Id: pageradapter.py 49679 2008-01-23 14:07:51Z cray $
+$Id: pageradapter.py 49951 2008-02-06 20:16:04Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49679 $"
+__version__ = "$Revision: 49951 $"
 
 from zope.interface import implements,Interface
 from zope.component import adapts
@@ -45,11 +45,9 @@ class PagerAdapter(object):
         if size :
             self.size = size 
         try :            
-            registry = getUtility(IRegistry,context=self.context)
-        except LookupError :
+            IRegistry(self.context).export(self,'orphan','size','revert')
+        except TypeError :
             pass
-        else :                        
-            registry.export(self,'orphan','size','revert')
 
     def getOb(self,key) :
         return self.context[key]
